AbstractExpression
==================

.. currentmodule:: pqp.symbols

.. autoclass:: AbstractExpression
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~AbstractExpression.assign
      ~AbstractExpression.copy
      ~AbstractExpression.free_variables
      ~AbstractExpression.intervene
      ~AbstractExpression.r_adapt_map
      ~AbstractExpression.r_map
      ~AbstractExpression.sorted
      ~AbstractExpression.syntactic_eq

   .. rubric:: Methods Documentation

   .. automethod:: assign
   .. automethod:: copy
   .. automethod:: free_variables
   .. automethod:: intervene
   .. automethod:: r_adapt_map
   .. automethod:: r_map
   .. automethod:: sorted
   .. automethod:: syntactic_eq
